@@ -1,18 +1,18 @@
 <?php
-/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-06-05 10:51:35
+/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-06-28 16:14:49
   from "ls:top.tpl" */
 
 /* @var Smarty_Internal_Template $_smarty_tpl */
 if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
   'version' => '3.1.31',
-  'unifunc' => 'content_5cf79eb7e036f4_11936531',
+  'unifunc' => 'content_5d1620d9624304_78967743',
   'has_nocache_code' => false,
   'file_dependency' => 
   array (
     'f42923f474b713ac9da912d26a6790568d7df7dd' => 
     array (
       0 => 'ls:top.tpl',
-      1 => 1559731651,
+      1 => 1560771352,
       2 => 'ls',
     ),
   ),
@@ -21,7 +21,7 @@ if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
     'ls:LSdefault.tpl' => 1,
   ),
 ),false)) {
-function content_5cf79eb7e036f4_11936531 (Smarty_Internal_Template $_smarty_tpl) {
+function content_5d1620d9624304_78967743 (Smarty_Internal_Template $_smarty_tpl) {
 if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
 ?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
@@ -72,7 +72,7 @@ if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/s
       <form action='global_search.php' method='post' class='LSview_search LSglobal_search'>
         <input type='hidden' name='LSsearch_submit' value='1'/>
         <input type='text' name='pattern' class='LSview_search LSglobal_search' placeholder='<?php echo LStemplate_smarty_tr(array('msg'=>'Global search'),$_smarty_tpl);?>
-'/>
+' required="required"/>
         <input type='image' src='<?php echo LStemplate_smarty_img(array('name'=>'find'),$_smarty_tpl);?>
 ' alt='<?php echo LStemplate_smarty_tr(array('msg'=>'Global search'),$_smarty_tpl);?>
 ' title='<?php echo LStemplate_smarty_tr(array('msg'=>'Global search'),$_smarty_tpl);?>
